/**
 * @file
 * This header file declares the function to create one instance of the CrIaCentValProc procedure.
 * The procedure is configured with a set of function pointers representing the non-default
 * actions and guards of the procedure. Some of these functions may also be declared in
 * this header file in accordance with the configuration of the procedure in the FW Profile
 * Editor. In the latter case, the user has to provide an implementation for these functions
 * in a user-supplied body file.
 *
 * This header file has been automatically generated by the FW Profile Editor.
 * The procedure created by this file is shown in the figure below.
 * @image html CrIaCentValProc.png
 *
 * @author FW Profile code generator version 4.63
 * @date Created on: Feb 11 2016 22:56:46
 */

/** Make sure to include this header file only once */
#ifndef CrIaCentValProcCreate_H_
#define CrIaCentValProcCreate_H_

/** FW Profile function definitions */
#include "FwProfile/FwPrConstants.h"

/** Action node identifiers */
#define CrIaCentValProc_N1 1		/* The identifier of action node N1 in procedure CrIaCentValProc */
#define CrIaCentValProc_N2 2		/* The identifier of action node N2 in procedure CrIaCentValProc */
#define CrIaCentValProc_N3 3		/* The identifier of action node N3 in procedure CrIaCentValProc */

/**
 * Create a new procedure descriptor.
 * This interface creates the procedure descriptor dynamically.
 * @param prData the pointer to the procedure data.
 * A value of NULL is legal (note that the default value of the pointer
 * to the procedure data when the procedure is created is NULL).
 * @return the pointer to the procedure descriptor
 */
FwPrDesc_t CrIaCentValProcCreate(void* prData);

/**
 * Action for node N1.
 * <pre>
 * Set centValProcOutput to
 * indicate that the centroid is invalid
 * </pre>
 * @param smDesc the procedure descriptor
 */
void CrIaCentValProcN1(FwPrDesc_t prDesc);

/**
 * Action for node N2.
 * <pre>
 * Set centValProcOutput to
 * the same value as ValidityStatus
 * </pre>
 * @param smDesc the procedure descriptor
 */
void CrIaCentValProcN2(FwPrDesc_t prDesc);

/**
 * Action for node N3.
 * <pre>
 * Generate event
 * EVT_INV_CENT
 * </pre>
 * @param smDesc the procedure descriptor
 */
void CrIaCentValProcN3(FwPrDesc_t prDesc);

/**
 * Guard on the Control Flow from DECISION2 to N1.
 * <pre>
 *  The position of the target is outside
 * the instrument field of view 
 * </pre>
 * @param smDesc the procedure descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwPrBool_t CrIaCentValProcIsOutFOV(FwPrDesc_t prDesc);

/**
 * Guard on the Control Flow from DECISION3 to N1.
 * <pre>
 *  Distance between desired and measured position
 * of target is greater than CENT_OFFSET_LIM 
 * of size of instrument field of view 
 * </pre>
 * @param smDesc the procedure descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwPrBool_t CrIaCentValProcIsDistLarge(FwPrDesc_t prDesc);

/**
 * Guard on the Control Flow from DECISION4 to N1.
 * <pre>
 *  (More than CENT_FROZEN_LIM centroids have been 
 * computed since IASW was started) && 
 * (Last CENT_FROZEN_LIM centroids are identical) 
 * </pre>
 * @param smDesc the procedure descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwPrBool_t CrIaCentValProcIsFrozen(FwPrDesc_t prDesc);

#endif /* CrIaCentValProcCreate_H_ */