/**
 * @file
 * This header file declares the function to create one instance of the CrIaIasw state machine.
 * The state machine is configured with a set of function pointers representing the non-default
 * actions and guards of the state machine. Some of these functions may also be declared in
 * this header file in accordance with the configuration of the state machine in the FW Profile
 * Editor. In the latter case, the user has to provide an implementation for these functions
 * in a user-supplied body file.
 *
 * This header file has been automatically generated by the FW Profile Editor.
 * The state machine created by this file is shown in the figure below.
 * @image html CrIaIasw.png
 *
 * @author FW Profile code generator version 4.63
 * @date Created on: Feb 11 2016 22:56:45
 */

/** Make sure to include this header file only once */
#ifndef CrIaIaswCreate_H_
#define CrIaIaswCreate_H_

/** FW Profile function definitions */
#include "FwProfile/FwSmConstants.h"

/** State identifiers */
#define CrIaIasw_STOPPED (0)
#define CrIaIasw_PRE_SCIENCE (1)		/* The identifier of state PRE_SCIENCE in State Machine CrIaIasw */
#define CrIaIasw_SCIENCE (2)		/* The identifier of state SCIENCE in State Machine CrIaIasw */
#define CrIaIasw_SEM_OFFLINE (3)		/* The identifier of state SEM_OFFLINE in State Machine CrIaIasw */
#define CrIaIasw_STANDBY (4)		/* The identifier of state STANDBY in State Machine CrIaIasw */

/** The identifiers of transition commands (triggers) */
#define Execute (0)
#define StopSem (3)
#define PrepareScience (4)
#define StartOffline (6)
#define StartScience (7)
#define StopScience (5)

/**
 * Create a new state machine descriptor.
 * This interface creates the state machine descriptor dynamically.
 * @param smData the pointer to the state machine data.
 * A value of NULL is legal (note that the default value of the pointer
 * to the state machine data when the state machine is created is NULL).
 * @return the pointer to the state machine descriptor
 */
FwSmDesc_t CrIaIaswCreate(void* smData);

/**
 * Entry Action for the state STANDBY.
 * <pre>
 * Load EVT_IASW_TR
 * Send SwitchOff command
 *  to SEM Unit State Machine
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaIaswSwitchOffSem(FwSmDesc_t smDesc);

/**
 * Entry Action for the state PRE_SCIENCE.
 * <pre>
 * Load EVT_IASW_TR
 * Start Prepare
 * Science Procedure
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaIaswStartPrepSci(FwSmDesc_t smDesc);

/**
 * Do Action for the state PRE_SCIENCE.
 * <pre>
 * Execute Prepare
 * Science Procedure
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaIaswExecPrepSci(FwSmDesc_t smDesc);

/**
 * Entry Action for the state SCIENCE.
 * <pre>
 * Load EVT_IASW_TR
 * Load (196,1) Report
 * Enable Centroid Cons. FdCheck
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaIaswLoad196s1(FwSmDesc_t smDesc);

/**
 * Exit Action for the state SCIENCE.
 * <pre>
 * Stop all Science Procedures
 * Stop all Science Algorithms
 * Disable Centroid Cons. FdCheck
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaIaswScienceExit(FwSmDesc_t smDesc);

/**
 * Do Action for the state SCIENCE.
 * Execute all Science Procedures
 * but the Save Images and Transfer
 * FBFs to Ground Procedures
 * @param smDesc the state machine descriptor
 */
void CrIaIaswExecAllSciPr(FwSmDesc_t smDesc);

/**
 * Entry Action for the state SEM_OFFLINE.
 * <pre>
 * Load EVT_IASW_TR
 * Send SwitchOn command
 * to SEM Unit State Machine
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaIaswSwitchOnSem(FwSmDesc_t smDesc);

/**
 * Action on the transition from PRE_SCIENCE to CHOICE1.
 * Action_1
 * @param smDesc the state machine descriptor
 */
void CrIaIaswSMAction1(FwSmDesc_t smDesc);

/**
 * Guard on the transition from PRE_SCIENCE to SCIENCE.
 *  Flag_1 
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaIaswFlag1(FwSmDesc_t smDesc);

/**
 * Guard on the transition from SCIENCE to PRE_SCIENCE.
 * <pre>
 *  All Science Procedures controlled
 * by do-action of SCIENCE have
 * terminated execution 
 * </pre>
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaIaswAreSciPrTerm(FwSmDesc_t smDesc);

#endif /* CrIaIaswCreate_H_ */
