/**
 * @file
 * This header file declares the function to create one instance of the CrIaSdb state machine.
 * The state machine is configured with a set of function pointers representing the non-default
 * actions and guards of the state machine. Some of these functions may also be declared in
 * this header file in accordance with the configuration of the state machine in the FW Profile
 * Editor. In the latter case, the user has to provide an implementation for these functions
 * in a user-supplied body file.
 *
 * This header file has been automatically generated by the FW Profile Editor.
 * The state machine created by this file is shown in the figure below.
 * @image html CrIaSdb.png
 *
 * @author FW Profile code generator version 4.63
 * @date Created on: Feb 11 2016 22:56:45
 */

/** Make sure to include this header file only once */
#ifndef CrIaSdbCreate_H_
#define CrIaSdbCreate_H_

/** FW Profile function definitions */
#include "FwProfile/FwSmConstants.h"

/** State identifiers */
#define CrIaSdb_CONFIG_FULL 1		/* The identifier of state CONFIG_FULL in State Machine CrIaSdb */
#define CrIaSdb_CONFIG_WIN 2		/* The identifier of state CONFIG_WIN in State Machine CrIaSdb */
#define CrIaSdb_UNCONFIGURED 3		/* The identifier of state UNCONFIGURED in State Machine CrIaSdb */

/** The identifiers of transition commands (triggers) */
#define ConfigFull 21
#define ConfigWin 22
#define ResetFull 23
#define Reset 2
#define ResetWin 24

/**
 * Create a new state machine descriptor.
 * This interface creates the state machine descriptor dynamically.
 * @param smData the pointer to the state machine data.
 * A value of NULL is legal (note that the default value of the pointer
 * to the state machine data when the state machine is created is NULL).
 * @return the pointer to the state machine descriptor
 */
FwSmDesc_t CrIaSdbCreate(void* smData);

/**
 * Entry Action for the state CONFIG_FULL.
 * <pre>
 * Initialize sibIn, sibOut, cibIn and 
 * gibIn to point to first SIB, CIB and 
 * GIB for CCD Full images.
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSdbConfigFullEntry(FwSmDesc_t smDesc);

/**
 * Entry Action for the state CONFIG_WIN.
 * <pre>
 * Initialize sibIn, sibOut, cibIn and 
 * gibIn to point to first SIB, CIB and 
 * GIB for CCD Window images.
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSdbConfigWinEntry(FwSmDesc_t smDesc);

/**
 * Action on the transition from UNCONFIGURED to CHOICE1.
 * Action_1
 * @param smDesc the state machine descriptor
 */
void CrIaSdbAction1(FwSmDesc_t smDesc);

/**
 * Action on the transition from CHOICE2 to CONFIG_WIN.
 * Action_2
 * @param smDesc the state machine descriptor
 */
void CrIaSdbAction2(FwSmDesc_t smDesc);

/**
 * Guard on the transition from CHOICE2 to CONFIG_WIN.
 * <pre>
 *  SDB Configuration was
 * successful 
 * </pre>
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaSdbIsConfigSuccess(FwSmDesc_t smDesc);

/**
 * Guard on the transition from CHOICE2 to UNCONFIGURED.
 * <pre>
 *  SDB Configuration
 * failed 
 * </pre>
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaSdbIsConfigFailed(FwSmDesc_t smDesc);

#endif /* CrIaSdbCreate_H_ */