/**
 * @file
 * This header file declares the function to create one instance of the CrIaSdu state machine.
 * The state machine is configured with a set of function pointers representing the non-default
 * actions and guards of the state machine. Some of these functions may also be declared in
 * this header file in accordance with the configuration of the state machine in the FW Profile
 * Editor. In the latter case, the user has to provide an implementation for these functions
 * in a user-supplied body file.
 *
 * This header file has been automatically generated by the FW Profile Editor.
 * The state machine created by this file is shown in the figure below.
 * @image html CrIaSdu.png
 *
 * @author FW Profile code generator version 4.63
 * @date Created on: Feb 11 2016 22:56:45
 */

/** Make sure to include this header file only once */
#ifndef CrIaSduCreate_H_
#define CrIaSduCreate_H_

/** FW Profile function definitions */
#include "FwProfile/FwSmConstants.h"

/** State identifiers */
#define CrIaSdu_DOWN_TRANSFER (1)		/* The identifier of state DOWN_TRANSFER in State Machine CrIaSdu */
#define CrIaSdu_INACTIVE (2)		/* The identifier of state INACTIVE in State Machine CrIaSdu */
#define CrIaSdu_UP_TRANSFER (3)		/* The identifier of state UP_TRANSFER in State Machine CrIaSdu */

/** The identifiers of transition commands (triggers) */
#define Execute (0)
#define Abort (18)
#define StartDownTransfer (19)
#define StartUpTransfer (20)

/**
 * Create a new state machine descriptor.
 * This interface creates the state machine descriptor dynamically.
 * @param smData the pointer to the state machine data.
 * A value of NULL is legal (note that the default value of the pointer
 * to the state machine data when the state machine is created is NULL).
 * @return the pointer to the state machine descriptor
 */
FwSmDesc_t CrIaSduCreate(void* smData);

/**
 * Entry Action for the state DOWN_TRANSFER.
 * <pre>
 * sduxBlockCnt = 0;
 * if (down transfer is for SDU2) {
 *  use as SDU2 the GIB pointed at by gibOut; 
 *  sdu2DownTransferSize = size of most recently updated GIB; 
 *  sdu2RemSize = sdu2DownTransferSize; }
 * if (down-transfer is for SDU3) {
 *  use as SDU3 the HK Storage;
 *  sdu3DownTransferSize = size of HK Storage; 
 *  sdu3RemSize = sdu3DownTransferSize; }
 * if (down-transfer is for SDU4) && (sdu4DownTransferSize==0xFFFFFFF)
 *  sdu4DownTransferSize = size of valid data of FBF in SDU4; }
 * if (down-transfer is for SDU4) && (sdu4DownTransferSize!=0xFFFFFFF)
 *  sdu4RemSize = sdu4DownTransferSize; }
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSduDownTransferEntry(FwSmDesc_t smDesc);

/**
 * Do Action for the state DOWN_TRANSFER.
 * <pre>
 * dtSize = 0;
 * Retrieve dtCapacity from IBSW;
 * if (Flag_2) dtSize = dtCapacity;
 * If (dtSize > 0) sduxBlockCnt++ 
 * sduxRemSize = sduxRemSize - dtSize;
 * if ((dtSize>0) && (sduxBlockCnt == 1)) Load TM(13,1) 
 * if ((dtSize>0) && (sduxBlockCnt > 1) && (sduxRemSize>0)) {
 *  Load TM(13,2) }
 * if ((dtSize>0) && (sduxBlockCnt > 1) && (sduxRemSize<=0)) {
 *  Load TM(13,3) }
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSduDownTransferDo(FwSmDesc_t smDesc);

/**
 * Action on the transition from DOWN_TRANSFER to INACTIVE.
 * <pre>
 * 
 * Load (13,4) Report
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSduLoad13s4Rep(FwSmDesc_t smDesc);

/**
 * Action on the transition from UP_TRANSFER to INACTIVE.
 * <pre>
 * 
 * Load (13,16) Report
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSduLoad13s16Rep(FwSmDesc_t smDesc);

/**
 * Guard on the transition from UP_TRANSFER to INACTIVE.
 *  Transfer is finished  
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaSduIsTransferFinished(FwSmDesc_t smDesc);

/**
 * Action on the transition from Initial State to INACTIVE.
 * sdsCounter = 0
 * @param smDesc the state machine descriptor
 */
void CrIaSduResetSdsCounter(FwSmDesc_t smDesc);

/**
 * Guard on the transition from CHOICE1 to DOWN_TRASFER.
 *  Flag_1 
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaSduIsFlag1(FwSmDesc_t smDesc);

/**
 * Action on the transition from CHOICE1 to INACTIVE.
 * sdsCounter++
 * @param smDesc the state machine descriptor
 */
void CrIaSduIncrSdsCounter(FwSmDesc_t smDesc);

#endif /* CrIaSduCreate_H_ */
