/**
 * @file
 * This header file declares the function to create one instance of the CrIaTTC1 procedure.
 * The procedure is configured with a set of function pointers representing the non-default
 * actions and guards of the procedure. Some of these functions may also be declared in
 * this header file in accordance with the configuration of the procedure in the FW Profile
 * Editor. In the latter case, the user has to provide an implementation for these functions
 * in a user-supplied body file.
 *
 * This header file has been automatically generated by the FW Profile Editor.
 * The procedure created by this file is shown in the figure below.
 *
 * <b>Note for Control Flow from DECISION1 to N4</b>
 * This procedure may run either on the aft 
 * thermistors and the aft heaters or on the 
 * front thermistors and the front heaters.
 *
 * @image html CrIaTTC1.png
 *
 * @author FW Profile code generator version 4.63
 * @date Created on: Feb 11 2016 22:56:46
 */

/** Make sure to include this header file only once */
#ifndef CrIaTTC1Create_H_
#define CrIaTTC1Create_H_

/** FW Profile function definitions */
#include "FwProfile/FwPrConstants.h"

/** Action node identifiers */
#define CrIaTTC1_N1 1		/* The identifier of action node N1 in procedure CrIaTTC1 */
#define CrIaTTC1_N3 2		/* The identifier of action node N3 in procedure CrIaTTC1 */
#define CrIaTTC1_N4 3		/* The identifier of action node N4 in procedure CrIaTTC1 */

/**
 * Create a new procedure descriptor.
 * This interface creates the procedure descriptor dynamically.
 * @param prData the pointer to the procedure data.
 * A value of NULL is legal (note that the default value of the pointer
 * to the procedure data when the procedure is created is NULL).
 * @return the pointer to the procedure descriptor
 */
FwPrDesc_t CrIaTTC1Create(void* prData);

/**
 * Action for node N1.
 * <pre>
 * T = average of two middle
 * values of thermistor readings
 * </pre>
 * @param smDesc the procedure descriptor
 */
void CrIaTTC1ComputeTemp(FwPrDesc_t prDesc);

/**
 * Action for node N4.
 * <pre>
 * Ask IBSW to
 * switch off the heaters
 * </pre>
 * @param smDesc the procedure descriptor
 */
void CrIaTTC1SwitchOff(FwPrDesc_t prDesc);

/**
 * Action for node N3.
 * <pre>
 * Ask IBSW to
 * switch on the heaters 
 * </pre>
 * @param smDesc the procedure descriptor
 */
void CrIaTTC1SwitchOn(FwPrDesc_t prDesc);

/**
 * Guard on the Control Flow from DECISION1 to N3.
 *  T is below lower limit 
 * @param smDesc the procedure descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwPrBool_t CrIaTTC1IsTempTooLow(FwPrDesc_t prDesc);

/**
 * Guard on the Control Flow from DECISION1 to N4.
 *  T is above upper limit 
 * @param smDesc the procedure descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwPrBool_t CrIaTTC1IsTempTooHigh(FwPrDesc_t prDesc);

#endif /* CrIaTTC1Create_H_ */